/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISOAPResponseListener.idl
 */

#ifndef __gen_nsISOAPResponseListener_h__
#define __gen_nsISOAPResponseListener_h__

#include "nsISupports.h"

class nsISOAPCall; /* forward declaration */

class nsISOAPResponse; /* forward declaration */


/* starting interface:    nsISOAPResponseListener */
#define NS_ISOAPRESPONSELISTENER_IID_STR "99ec6692-535f-11d4-9a58-000064657374"

#define NS_ISOAPRESPONSELISTENER_IID \
  {0x99ec6692, 0x535f, 0x11d4, \
    { 0x9a, 0x58, 0x00, 0x00, 0x64, 0x65, 0x73, 0x74 }}

class NS_NO_VTABLE nsISOAPResponseListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISOAPRESPONSELISTENER_IID)

  /**
   * This method is invoked when we receive an asynchronous response to 
   * a SOAP message. The listener is registered as part of the original
   * asynchronous call invocation. 
   *
   * @param response The decoded version of the response
   * @param call The SOAPCall object that triggered the response
   * @param status The protcol status from the call
   */
  /* void handleResponse (in nsISOAPResponse response, in nsISOAPCall call, in unsigned long status); */
  NS_IMETHOD HandleResponse(nsISOAPResponse *response, nsISOAPCall *call, PRUint32 status) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISOAPRESPONSELISTENER \
  NS_IMETHOD HandleResponse(nsISOAPResponse *response, nsISOAPCall *call, PRUint32 status); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISOAPRESPONSELISTENER(_to) \
  NS_IMETHOD HandleResponse(nsISOAPResponse *response, nsISOAPCall *call, PRUint32 status) { return _to ## HandleResponse(response, call, status); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSOAPResponseListener : public nsISOAPResponseListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISOAPRESPONSELISTENER

  nsSOAPResponseListener();
  virtual ~nsSOAPResponseListener();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSOAPResponseListener, nsISOAPResponseListener)

nsSOAPResponseListener::nsSOAPResponseListener()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsSOAPResponseListener::~nsSOAPResponseListener()
{
  /* destructor code */
}

/* void handleResponse (in nsISOAPResponse response, in nsISOAPCall call, in unsigned long status); */
NS_IMETHODIMP nsSOAPResponseListener::HandleResponse(nsISOAPResponse *response, nsISOAPCall *call, PRUint32 status)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISOAPResponseListener_h__ */
